S7 class for hespeR list of vectors
HesperList.RdS7 class for hespeR list of vectors
Usage
HesperList(hesper_list = list())Details
The HesperList class is designed to encapsulate a collection of HESPER vectors. Each vector in the list is an instance of the HesperVector class, representing a specific HESPER item and its allowed options.
The class validates that each item in the list is a valid HesperVector and that the list is not empty, has duplicated HESPER items, has different lengths of hesper_vals, and has consistent allow_missing values across all items.