S7 class for HESPER skip logic (SL)
SL.RdS7 class for HESPER skip logic (SL)
Details
The SL class is designed to encapsulate the properties of a skip logic rule in HESPER. It includes the name of the HESPER variable, the name of the subset variable, and the values in the subset variable.
The class validates that:
The
hesper_varproperty is a valid HESPER variable.The
subset_varproperty is a character string.The
subset_valsproperty is a vector with at least one value.