Check for missing variables in a data frame
Usage
check_missing_vars(df, vars, property = "hesper_vars")
Arguments
- df
(data.frame[,1+]) A data frame
- vars
(character[1+]) Names of variables to check for in the data frame.
- property
(character[1] | NULL) Property being checked (default: 'hesper_vars').
Value
(TRUE | error) TRUE if all variables are present, otherwise throws an error.